/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.portals.applications.webcontent2.proxy;

/**
 * The <CODE>ReverseProxyException</CODE> class defines a general exception
 * that an http reverse proxy component can throw when it is unable to perform its operation
 * successfully.
 */
public class ReverseProxyException extends Exception 
{

    private static final long serialVersionUID = 1L;

    /**
     * HTTP Response status code.
     */
    private int statusCode;

    /**
     * Constructs a new HttpReverseProxyException exception.
     */
    public ReverseProxyException() {
        super();
    }

    /**
     * Constructs a new HttpReverseProxyException exception.
     * 
     * @param statusCode
     *        the HTTP Response status code
     */
    public ReverseProxyException(int statusCode) {
        super();
        this.statusCode = statusCode;
    }

    /**
     * Constructs a new HttpReverseProxyException exception with the given message.
     *
     * @param   message
     *          the exception message
     */
    public ReverseProxyException(String message) {
        super(message);
    }

    /**
     * Constructs a new HttpReverseProxyException exception with the given message.
     *
     * @param statusCode
     *        the HTTP Response status code
     * @param   message
     *          the exception message
     */
    public ReverseProxyException(int statusCode, String message) {
        super(message);
        this.statusCode = statusCode;
    }

    /**
     * Constructs a new HttpReverseProxyException exception with the nested exception.
     *
     * @param   nested
     *          the nested exception
     */
    public ReverseProxyException(Throwable nested) {
        super(nested);
    }

    /**
     * Constructs a new HttpReverseProxyException exception with the nested exception.
     *
     * @param statusCode
     *        the HTTP Response status code
     * @param   nested
     *          the nested exception
     */
    public ReverseProxyException(int statusCode, Throwable nested) {
        super(nested);
        this.statusCode = statusCode;
    }

    /**
     * Constructs a new HttpReverseProxyException exception when the container needs to do
     * the following:
     * <ul>
     * <li>throw an exception 
     * <li>include the "nested" exception
     * <li>include a description message
     * </ul>
     *
     * @param   msg
     *          the exception message
     * @param   nested
     *          the nested exception
     */
    public ReverseProxyException(String msg, Throwable nested) {
        super(msg, nested);
    }

    /**
     * Constructs a new HttpReverseProxyException exception when the container needs to do
     * the following:
     * <ul>
     * <li>throw an exception 
     * <li>include the "nested" exception
     * <li>include a description message
     * </ul>
     *
     * @param statusCode
     *        the HTTP Response status code
     * @param   msg
     *          the exception message
     * @param   nested
     *          the nested exception
     */
    public ReverseProxyException(int statusCode, String msg, Throwable nested) {
        super(msg, nested);
        this.statusCode = statusCode;
    }

    /**
     * Returns HTTP Response status code
     * @return
     */
    public int getStatusCode()
    {
        return statusCode;
    }

}
